@@ -11,10 +11,7 @@ def _get_oidc_token(audience):
         from subprocess import Popen, PIPE
 
         return (
-            Popen(
-                ["gcloud", "auth", "print-identity-token", "--audiences=" + audience],
-                stdout=PIPE,
-            )
+            Popen(["gcloud", "auth", "print-identity-token"], stdout=PIPE)
             .communicate()[0][:-1]
             .decode()
         )
